@@ -29,6 +29,7 @@
 #include "ide-terminal.h"
 
 #define BUILDER_PCRE2_MULTILINE 0x00000400u
+#define BUILDER_PCRE2_UCP 0x00020000u
 
 typedef struct
 {
@@ -63,7 +64,7 @@ enum {
 /* From vteapp.c */
 #define DINGUS1 "(((gopher|news|telnet|nntp|file|http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+(:[0-9]*)?"
 #define DINGUS2 DINGUS1 "/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#\\%]*[^]'\\.}>\\) ,\\\"]"
-#define FILENAME_PLUS_LOCATION "(?<filename>[a-zA-Z0-9\\+\\-\\.\\/_]+):(?<line>\\d+):(?<column>\\d+)"
+#define FILENAME_PLUS_LOCATION "(?<filename>[[:alnum:]\\+\\-\\.\\/_]+):(?<line>\\d+):(?<column>\\d+)"
 
 static guint signals[N_SIGNALS];
 static const gchar *url_regexes[] = { DINGUS1, DINGUS2, FILENAME_PLUS_LOCATION };
@@ -95,14 +96,19 @@ static void
 style_context_changed (IdeTerminal *self,
                        GtkStyleContext *style_context)
 {
+  GtkStateFlags state;
   GdkRGBA fg;
   GdkRGBA bg;
 
   g_assert (GTK_IS_STYLE_CONTEXT (style_context));
   g_assert (IDE_IS_TERMINAL (self));
 
-  gtk_style_context_lookup_color (style_context, "theme_text_color", &fg);
-  gtk_style_context_lookup_color (style_context, "text_view_bg", &bg);
+  state = gtk_style_context_get_state (style_context);
+
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+  gtk_style_context_get_color (style_context, state, &fg);
+  gtk_style_context_get_background_color (style_context, state, &bg);
+  G_GNUC_END_IGNORE_DEPRECATIONS;
 
   if (bg.alpha == 0.0)
     gdk_rgba_parse (&bg, "#f6f7f8");
@@ -564,7 +570,7 @@ ide_terminal_init (IdeTerminal *self)
       gint tag;
 
       regex = vte_regex_new_for_match (pattern, DZL_LITERAL_LENGTH (pattern),
-                                       VTE_REGEX_FLAGS_DEFAULT | BUILDER_PCRE2_MULTILINE,
+                                       VTE_REGEX_FLAGS_DEFAULT | BUILDER_PCRE2_MULTILINE | BUILDER_PCRE2_UCP,
                                        NULL);
       tag = vte_terminal_match_add_regex (VTE_TERMINAL (self), regex, 0);
       vte_terminal_match_set_cursor_name (VTE_TERMINAL (self), tag, "hand2");
