@@ -352,7 +352,7 @@ gbp_buildui_workspace_addin_load (IdeWorkspaceAddin *addin,
   self->cancel_button = g_object_new (GTK_TYPE_BUTTON,
                                       "action-name", "build-manager.cancel",
                                       "child", g_object_new (GTK_TYPE_IMAGE,
-                                                             "icon-name", "process-stop-symbolic",
+                                                             "icon-name", "builder-build-stop-symbolic",
                                                              "visible", TRUE,
                                                              NULL),
                                       "focus-on-click", FALSE,
@@ -462,7 +462,7 @@ workspace_addin_iface_init (IdeWorkspaceAddinInterface *iface)
   iface->unload = gbp_buildui_workspace_addin_unload;
 }
 
-G_DEFINE_TYPE_WITH_CODE (GbpBuilduiWorkspaceAddin, gbp_buildui_workspace_addin, G_TYPE_OBJECT,
+G_DEFINE_FINAL_TYPE_WITH_CODE (GbpBuilduiWorkspaceAddin, gbp_buildui_workspace_addin, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (IDE_TYPE_WORKSPACE_ADDIN, workspace_addin_iface_init))
 
 static void
