@@ -21,7 +21,6 @@
 #define G_LOG_DOMAIN "gbp-flatpak-runner"
 
 #include <errno.h>
-#include <flatpak.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <unistd.h>
@@ -38,7 +37,7 @@ struct _GbpFlatpakRunner
   gchar *manifest_command;
 };
 
-G_DEFINE_TYPE (GbpFlatpakRunner, gbp_flatpak_runner, IDE_TYPE_RUNNER)
+G_DEFINE_FINAL_TYPE (GbpFlatpakRunner, gbp_flatpak_runner, IDE_TYPE_RUNNER)
 
 static IdeSubprocessLauncher *
 gbp_flatpak_runner_create_launcher (IdeRunner *runner)
