@@ -56,6 +56,7 @@ class GVlsService(Ide.Object):
     source_file = None
     build_monitor = None
     meson_compile_commands = ""
+    meson_targets_intro = ""
 
     @classmethod
     def from_context(klass, context):
@@ -126,6 +127,7 @@ class GVlsService(Ide.Object):
             self._supervisor = Ide.SubprocessSupervisor()
             self._supervisor.connect('spawned', self._gvls_spawned)
             self._supervisor.set_launcher(launcher)
+            Ide.debug('GVls server supervisor has been prepared')
             self._supervisor.start()
 
     def list_to_variant(self, l):
@@ -173,9 +175,12 @@ class GVlsService(Ide.Object):
             b.add_value(self.create_dict_entry_boolean('addUsingNamespaces', self.add_using_namespaces))
             b.add_value(self.create_dict_entry_boolean('mesonBuildSystem', self.meson_build_system))
             b.add_value(self.create_dict_entry_string('libraryVapi', self.library_vapidir))
+            Ide.debug('Library VAPI dir:{0}'.format(self.library_vapidir))
             b.add_value(self.create_dict_entry_string('systemVapi', self.system_vapidir))
+            Ide.debug('System VAPI dir:{0}'.format(self.system_vapidir))
             b.add_value(self.create_dict_entry_string('valaApiVersion', self.vala_api_version))
             b.add_value(self.create_dict_entry_string('mesonCompileCommands', self.meson_compile_commands))
+            b.add_value(self.create_dict_entry_string('mesonTargetsIntro', self.meson_targets_intro))
             ad = GLib.Variant.new_string ('valaArgs')
             vadi = self.dict_to_array_variant(self.vala_args)
             adi = GLib.Variant.new_dict_entry(ad, GLib.Variant.new_variant (vadi))
@@ -204,6 +209,13 @@ class GVlsService(Ide.Object):
         if event_type == Gio.FileMonitorEvent.DELETED:
             self.build_monitor = None
 
+    def read_meson_targets_intro(self, file):
+        ostream = Gio.MemoryOutputStream.new_resizable()
+        ostream.splice(file.read(), Gio.OutputStreamSpliceFlags.CLOSE_SOURCE, None)
+        ostream.close()
+        b = ostream.steal_as_bytes()
+        self.meson_targets_intro = str(b.get_data(),encoding='utf8')
+
     def read_meson_compile_commands(self, file):
         ostream = Gio.MemoryOutputStream.new_resizable()
         ostream.splice(file.read(), Gio.OutputStreamSpliceFlags.CLOSE_SOURCE, None)
@@ -224,16 +236,22 @@ class GVlsService(Ide.Object):
                         bcf = Gio.File.new_for_uri(bcdir.get_uri()+'/compile_commands.json')
                         if not bcf.query_exists(None):
                             return
-                        self.read_meson_compile_commands(bcf)
-                        if self.build_monitor == None:
-                            self.build_monitor = bcf.monitor(Gio.FileMonitorFlags.NONE, None)
-                            self.build_monitor.connect('changed', self._build_config_changed)
-                        cc = Ide.CompileCommands.new()
-                        cc.load (bcf)
-                        commands = cc.lookup (self.source_file, '')
-                        if commands != None:
-                            self.build_args = commands[0]
-            
+                        mtf = Gio.File.new_for_uri(bcdir.get_uri()+'/meson-info/intro-targets.json')
+                        if not mtf.query_exists(None):
+                            self.read_meson_compile_commands(bcf)
+                            if self.build_monitor == None:
+                                self.build_monitor = bcf.monitor(Gio.FileMonitorFlags.NONE, None)
+                                self.build_monitor.connect('changed', self._build_config_changed)
+                            cc = Ide.CompileCommands.new()
+                            cc.load (bcf)
+                            commands = cc.lookup (self.source_file, '')
+                            if commands != None:
+                                self.build_args = commands[0]
+                        else:
+                            self.read_meson_targets_intro(mtf)
+                            if self.build_monitor == None:
+                                self.build_monitor = mtf.monitor(Gio.FileMonitorFlags.NONE, None)
+                                self.build_monitor.connect('changed', self._build_config_changed)
             self.files = []
             self.packages = []
             self.vala_args = {}
@@ -384,11 +402,18 @@ class GVlsService(Ide.Object):
                 break
         return self.create_configuration_variant()
     
+    def _on_pipeline_loaded(self, obj):
+        try:
+            Ide.debug('GVls: Pipeline loaded')
+            self._notify_change_configuration()
+        except BaseException as exc:
+            Ide.debug('On Pipeline Loaded start get build flags error: {}'.format(exc.args))
+
     def _on_pipeline_diagnostic(self, obj, diagnostic):
         try:
             self.source_file = diagnostic.get_file()
         except BaseException as exc:
-            Ide.debug('On Pipeline Loaded start get build flags error: {}'.format(exc.args))
+            Ide.debug('On Pipeline diagnostics start get build flags error: {}'.format(exc.args))
 
     def on_get_vala_data_dir(self, vdp, cancellable, data):
         try:
@@ -511,6 +536,7 @@ class GVlsService(Ide.Object):
                 self.meson_build_system = False
             buildmgr = Ide.BuildManager.from_context (ctx)
             self.pipeline = buildmgr.get_pipeline ()
+            self.pipeline.connect('loaded', self._on_pipeline_loaded)
             self.pipeline.connect('diagnostic', self._on_pipeline_diagnostic)
             cfgmgr = Ide.ConfigManager.from_context(ctx)
             cfgmgr.connect('notify::current', self.on_config_changed_cb)
@@ -536,10 +562,6 @@ class GVlsService(Ide.Object):
 
     @classmethod
     def bind_client(klass, provider):
-        """
-        This helper tracks changes to our client as it might happen when
-        our `org.gnome.gvls.Server` process has crashed.
-        """
         context = provider.get_context()
         self = GVlsService.from_context(context)
         self._ensure_started()
@@ -556,7 +578,7 @@ class GVlsCompletionProvider(Ide.LspCompletionProvider, Ide.CompletionProvider):
     def do_get_priority(self, context):
         # This provider only activates when it is very likely that we
         # want the results. So use high priority (negative is better).
-        return -1000
+        return -900
 
 class GVlsHighlighter(Ide.LspHighlighter, Ide.Highlighter):
     def do_load(self):
@@ -572,3 +594,7 @@ class GVlsHoverProvider(Ide.LspHoverProvider, Ide.HoverProvider):
         self.props.priority = 200
         GVlsService.bind_client(self)
 
+class GVlsFormatter(Ide.LspFormatter, Ide.Formatter):
+    def do_load(self):
+        GVlsService.bind_client(self)
+
