@@ -285,7 +285,7 @@ on_run_manager_run (GbpTerminalWorkspaceAddin *self,
       self->run_panel = g_object_new (DZL_TYPE_DOCK_WIDGET,
                                       "child", self->run_terminal,
                                       "expand", TRUE,
-                                      "icon-name", "media-playback-start-symbolic",
+                                      "icon-name", "builder-run-start-symbolic",
                                       "title", _("Application Output"),
                                       "visible", TRUE,
                                       NULL);
@@ -456,10 +456,11 @@ gbp_terminal_workspace_addin_load (IdeWorkspaceAddin *addin,
                         G_CALLBACK (gtk_widget_destroyed),
                         &self->bottom);
       gtk_container_add (GTK_CONTAINER (self->bottom_dock), GTK_WIDGET (self->bottom));
+      dzl_dock_item_present (DZL_DOCK_ITEM (self->bottom_dock));
 
       workbench = ide_widget_get_workbench (GTK_WIDGET (workspace));
 
-      if (ide_workbench_has_project (workbench))
+      if (ide_workbench_has_project (workbench) && IDE_IS_PRIMARY_WORKSPACE (workspace))
         {
           /* Setup terminals when a project is run */
           context = ide_widget_get_context (GTK_WIDGET (workspace));
@@ -585,7 +586,7 @@ workspace_addin_iface_init (IdeWorkspaceAddinInterface *iface)
   iface->unload = gbp_terminal_workspace_addin_unload;
 }
 
-G_DEFINE_TYPE_WITH_CODE (GbpTerminalWorkspaceAddin, gbp_terminal_workspace_addin, G_TYPE_OBJECT,
+G_DEFINE_FINAL_TYPE_WITH_CODE (GbpTerminalWorkspaceAddin, gbp_terminal_workspace_addin, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (IDE_TYPE_WORKSPACE_ADDIN, workspace_addin_iface_init))
 
 static void
